@@ -1,5 +1,5 @@
 package App::Wallflower;
-$App::Wallflower::VERSION = '1.012';
+$App::Wallflower::VERSION = '1.013';
 use strict;
 use warnings;
 
@@ -46,7 +46,15 @@ my @callbacks = (
         tap => sub {
             my ( $url, $response ) = @_;
             my ( $status, $headers, $file ) = @$response;
-            is( $status, 200, $url->path );
+            if ( $status == 301 ) {
+                my $i = 0;
+                $i += 2
+                  while $i < @$headers && lc( $headers->[$i] ) ne 'location';
+                diag( "$url => " . ( $headers->[ $i + 1 ] || '?' ) );
+            }
+            else {
+                is( $status, 200, $url->path );
+            }
         },
     ],
 );
@@ -416,7 +424,7 @@ sub _process_queue {
         elsif ( $status eq '301' ) {
             require HTTP::Headers;
             my $l = HTTP::Headers->new(@$headers)->header('Location');
-            unshift @queue, $l if $l;
+            $self->_push_todo($l) if $l;
         }
     }
 }
@@ -441,7 +449,7 @@ App::Wallflower - Class performing the moves for the wallflower program
 
 =head1 VERSION
 
-version 1.012
+version 1.013
 
 =head1 SYNOPSIS
 
